@@ -134,9 +134,6 @@ def answer(
 
                                     # Check for finish reason to yield final status and stop iteration
                                     if finish_reason:
-                                        logger.info(
-                                            f"Stream finished with reason: {finish_reason}"
-                                        )
                                         yield {"type": "finish", "data": finish_reason}
                                         break  # Stop processing lines after finish
                             except json.JSONDecodeError:
@@ -274,9 +271,6 @@ class DeepSeekClient(LLMClient):
         super().__init__(
             model=resolved_model, api_key=resolved_api_key
         )  # Pass resolved values to base
-        print(
-            f"INFO: Using DeepSeek model: {self.model}", file=sys.stderr
-        )  # Info message
 
     def _format_history(
         self, system_prompt: str, history: List[Dict[str, str]]
@@ -335,3 +329,42 @@ class DeepSeekClient(LLMClient):
             error_message = f"DeepSeek API Error: Unexpected response type ({type(response_content)}) for non-streaming call."
             logger.error(error_message)
             return None, error_message
+
+    def generate_content_stream(self, system_prompt: str, history: List[Dict[str, str]]):
+        """
+        Streams content from the DeepSeek API via the answer() helper, yielding text chunks.
+        On error, yields a single 'STREAMING_ERROR: ...' message.
+        """
+        try:
+            formatted_messages = self._format_history(system_prompt, history)
+            stream_gen = answer(
+                messages=formatted_messages,
+                model=self.model,
+                api_key=self._api_key,
+                stream=True,
+            )
+
+            for item in stream_gen:
+                try:
+                    item_type = item.get("type")
+                except Exception:
+                    # Defensive: if unexpected type
+                    continue
+
+                if item_type == "content":
+                    data = item.get("data")
+                    if data:
+                        yield data
+                elif item_type == "error":
+                    err = item.get("data") or "Unknown error"
+                    yield f"STREAMING_ERROR: DeepSeek streaming error: {err}"
+                    break
+                elif item_type == "finish":
+                    break
+                else:
+                    # Ignore other event types for now (e.g., tool_calls)
+                    continue
+
+        except Exception as e:
+            import traceback
+            yield f"STREAMING_ERROR: Unexpected error during DeepSeek streaming: {e}\n{traceback.format_exc()}"
